@@ -27,6 +27,10 @@ def create_app(config):
     if app.config.get('MONGO_URI'):
         init_mongodb(app)
 
+    if app.config.get('REDIS_URL'):
+        init_redis(app)
+
+ 
     from .processor import Processor
     app.logger.info('初始化任务处理器...')
     processor = Processor()
@@ -76,7 +80,10 @@ def unload_modules():
             uninit_app(app)
         except:
             app.logger.warning('Unload Module [{}] Error.'.format(module.__name__))
-
+def init_redis(app):
+    from flask_redis import FlaskRedis
+    redis_client = FlaskRedis(app)
+    app.redis = redis_client
 def init_sqlalchemy(app):
     from flask_sqlalchemy import SQLAlchemy
     app.logger.info('初始化数据库...')
